<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:dict="http://xml.apache.org/xalan/java/Dictionary"
  exclude-result-prefixes="dict">

  <!--The following strips newlines introduced by elements, in particular introduced around the MajorVersion template match
	  See http://stackoverflow.com/questions/3265244/removing-blank-lines-in-xslt
	  and http://msdn.microsoft.com/en-us/library/ms256107.aspx -->
  <xsl:strip-space elements="*"/>
  
  <xsl:variable name="diction" select="dict:new('en')"/>

  <xsl:template match="Heading">
    <p><b><i><xsl:apply-templates select="Text"/></i></b></p>
  </xsl:template>

  <xsl:template match="NumberedItem">
    <ol><xsl:attribute name="start"><xsl:number/></xsl:attribute>
	<li>
	<xsl:for-each select="node()">
	  <xsl:apply-templates select="."/><!--<xsl:if test="self::Text and preceding-sibling::Text"><p/></xsl:if>-->
	</xsl:for-each>
      </li>
    </ol>
  </xsl:template>

  <xsl:template match="BulletList">
    <ul style="list-style-type: disc;">
      <xsl:for-each select="Bullet">
	<li><xsl:apply-templates/></li>
      </xsl:for-each>
    </ul>
    <p/>
  </xsl:template>

  <xsl:template match="Text">
    <xsl:apply-templates/><xsl:if test="parent::Content|parent::NumberedItem"><p/></xsl:if>
  </xsl:template>
  
  <xsl:template match="Comment">
    <p><i><xsl:apply-templates/></i></p>
  </xsl:template>
  
  <xsl:template match="Indent">
    <p><div style="margin-left: 2em;">
	<xsl:apply-templates/>
      </div></p>
  </xsl:template>

  <xsl:template match="span|img|table|b|br|td|tr|u">
    <xsl:copy><xsl:for-each select="@*"><xsl:copy/></xsl:for-each>
	<xsl:apply-templates/>
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="i">
    <xsl:choose>
      <xsl:when test="ancestor::Comment">
	<span style="font-style:normal;"><xsl:apply-templates/></span>
	</xsl:when>
      <xsl:otherwise>
	<i><xsl:apply-templates/></i>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="Link">
    <xsl:choose>
      <xsl:when test="not(parent::Text)">
	<p><div style="margin-left: 2em;">
	    <a><xsl:attribute name="href"><xsl:choose><xsl:when test="@url"><xsl:value-of select="@url"/></xsl:when><xsl:otherwise><xsl:value-of select="."/></xsl:otherwise></xsl:choose></xsl:attribute><xsl:value-of select="."/></a>
	  </div></p>
      </xsl:when>
      <xsl:otherwise>
	<a><xsl:attribute name="href"><xsl:choose><xsl:when test="@url"><xsl:value-of select="@url"/></xsl:when><xsl:otherwise><xsl:value-of select="."/></xsl:otherwise></xsl:choose></xsl:attribute><xsl:value-of select="."/></a>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="TutorialRef">
    <xsl:variable name="ref" select="@id"/>
    <a href="{@id}.htm"><xsl:value-of select="/TutorialList/Tutorial[@id=$ref]/Title/Text"/></a>
  </xsl:template>

  <xsl:template match="Path">
    <xsl:choose>
      <xsl:when test="not(parent::Text)">
	<p><div style="margin-left: 2em;">
	    <i><xsl:value-of select="."/></i>
	  </div></p>
      </xsl:when>
      <xsl:otherwise>
	<i><xsl:value-of select="."/></i>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  
  <xsl:template match="Menu">
    <xsl:choose>
      <xsl:when test="not(parent::Text)">
	<p><div style="margin-left: 2em;">
	    <b><xsl:apply-templates/></b>
	  </div></p>
      </xsl:when>
      <xsl:otherwise>
	<b><xsl:apply-templates/></b>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

 
  <xsl:template match="Format|Command">
    <xsl:choose>
      <xsl:when test="not(parent::Text)">
	<p><div style="margin-left: 2em;">
	  <small><tt><xsl:apply-templates/></tt></small>
	</div></p>
      </xsl:when>
      <xsl:otherwise>
	<small><tt><xsl:apply-templates/></tt></small>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="Indent">
    <div style="margin-left: 2em;">
      <xsl:apply-templates/>
    </div>
    <p/>
  </xsl:template>

  <xsl:template match="highlight">
    <span style="background-color: lightgrey;"><xsl:apply-templates/></span>
  </xsl:template>

<!-- old question and answer templates 
  <xsl:template match="Question">
    <span style="float:right;text-align:right;"><i><xsl:apply-templates select="following-sibling::Answer" mode="output"/></i></span><xsl:apply-templates/>
  </xsl:template>
  
  <xsl:template match="Answer" mode="output">
    <xsl:apply-templates/>
  </xsl:template>
-->

  <!-- Don't output the Answers, or the Updated tags-->
  <xsl:template match="Answer|Updated"/>
  
  <!-- the supplementary bits -->
  <xsl:template match="Prerequisite" mode="individual">
    <xsl:variable name="ref" select="@id"/>
    <xsl:apply-templates select="/TutorialList/SupplementaryText/Text[@id='prereq']"/><xsl:text> </xsl:text><a href="{@id}.htm"><xsl:value-of select="/TutorialList/Tutorial[@id=$ref]/Title/Text"/></a><br/>
  </xsl:template>

  <xsl:template match="Prerequisite" mode="combined">
    <xsl:variable name="ref" select="@id"/>
    <xsl:apply-templates select="/TutorialList/SupplementaryText/Text[@id='prereq']"/><xsl:text> </xsl:text><a href="#{@id}"><xsl:value-of select="/TutorialList/Tutorial[@id=$ref]/Title/Text"/></a><br/>
  </xsl:template>

  <xsl:template match="Version">
    <xsl:apply-templates select="/TutorialList/SupplementaryText/Text[@id='original']"/><xsl:text> </xsl:text><xsl:value-of select="@initial"/><br/>
    <xsl:if test="not(@current=@initial)"><xsl:apply-templates select="/TutorialList/SupplementaryText/Text[@id='current']"/><xsl:text> </xsl:text><xsl:value-of select="@current"/></xsl:if>
  </xsl:template>

  <!-- Do not process any elements marked with MajorVersion and whose version does not 
       specifically match the requested greenstone major version (2 or 3) -->
  <!--To avoid multiple lines of whitespace around output, use 
	 <xsl:for-each select="node()"><xsl:apply-templates/></xsl:for-each>
	 This outputs the contents on its own separate line. 
	 To avoid thinking about unnecessary newlines and to avoid omitting any sub-xml items 
	 that need to be processed, we can instead have the following at the top of the file:
	 <xsl:strip-space elements="*"/> -->
  <xsl:template match="MajorVersion"> 
    <xsl:if test="$gs-major-version=@number">
      <xsl:apply-templates/>      
    </xsl:if>
  </xsl:template>

  <xsl:template name="SampleFiles">
    <xsl:param name="mode">web</xsl:param>
    <xsl:choose><xsl:when test="$mode='wiki'">
	<xsl:apply-templates select="/TutorialList/SupplementaryText/Text[@id='sample']"/><xsl:text> </xsl:text><xsl:for-each select="SampleFiles"><a href="../sample_files/{@folder}.zip"><xsl:value-of select="@folder"/>.zip</a><xsl:text>  </xsl:text></xsl:for-each><br/>
      </xsl:when>
      <xsl:otherwise>
	<xsl:apply-templates select="/TutorialList/SupplementaryText/Text[@id='sample']"/><xsl:text> </xsl:text><xsl:for-each select="SampleFiles"><xsl:value-of select="@folder"/><xsl:text>  </xsl:text></xsl:for-each><br/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="IndexLink">
    <xsl:param name="mode">individual</xsl:param>
    <xsl:choose><xsl:when test="$mode='individual'">
	<a href="index.html"><xsl:apply-templates select="/TutorialList/SupplementaryText/Text[@id='index']"/></a><br/>
      </xsl:when>
      <xsl:otherwise>
	<a href="#index"><xsl:apply-templates select="/TutorialList/SupplementaryText/Text[@id='index']"/></a><br/>
      </xsl:otherwise>
    </xsl:choose>
	
  </xsl:template>

  <xsl:template name="WikiLink">
    <a href="http://greenstone.sourceforge.net/wiki/index.php/Tutorial_exercises"><xsl:apply-templates select="/TutorialList/SupplementaryText/Text[@id='wiki']"/></a><br/>
  </xsl:template>

  <xsl:template match="AutoText">
    <xsl:variable name="value"><xsl:choose><xsl:when test="@key"><xsl:variable name="key" select="@key"/><xsl:variable name="args" select="@args"/><xsl:value-of select="dict:get($diction, $key, $args)"/></xsl:when><xsl:otherwise><xsl:value-of select="@text"/></xsl:otherwise></xsl:choose></xsl:variable>
   <xsl:choose>
      <xsl:when test="@type='button'">
	<b>&lt;<xsl:value-of select="$value"/>&gt;</b>
      </xsl:when>
      <xsl:when test="@type='quoted'">
	<xsl:text>"</xsl:text><xsl:value-of select="$value"/><xsl:text>"</xsl:text>
      </xsl:when>
      <xsl:when test="@type='italics'">
	<i><xsl:value-of select="$value"/></i>
      </xsl:when>      
      <xsl:when test="@type='plain'">
	<xsl:value-of select="$value"/>
      </xsl:when>      
      <xsl:otherwise>
	<b><xsl:value-of select="$value"/></b>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

</xsl:stylesheet>

